# Generated by Django 3.2.18 on 2023-06-14 15:49

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("digid_eherkenning", "0002_auto_20221102_1046"),
    ]

    operations = [
        migrations.AddField(
            model_name="digidconfiguration",
            name="artifact_resolve_content_type",
            field=models.CharField(
                choices=[
                    ("application/soap+xml", "application/soap+xml"),
                    ("text/xml", "text/xml"),
                ],
                default="application/soap+xml",
                help_text="'application/soap+xml' is considered legacy and modern brokers typically expect 'text/xml'.",
                max_length=100,
                verbose_name="resolve artifact binding content type",
            ),
        ),
    ]
