from .digid import (  # noqa
    DigiDAssertionConsumerServiceView,
    DigiDLoginView,
    DigiDLogoutView,
    DigidSingleLogoutRedirectView,
    DigidSingleLogoutSoapView,
)
from .eherkenning import (  # noqa
    eHerkenningAssertionConsumerServiceView,
    eHerkenningLoginView,
)
